from distutils.core import setup
import setuptools

setup(
  name = 'soyuz',
  packages = ['soyuz'],
  version = '0.0.1',
  description = 'NLTK API with SpaCy models.',
  long_description = '',
  author = '',
  license = '',
  url = 'https://github.com/alvations/soyuz',
  keywords = [],
  classifiers = [],
)
